/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.cepcoremonitor.plugin;

import org.tinygroup.cepcore.CEPCore;
import org.tinygroup.cepcore.CEPCoreWatch;
import org.tinygroup.cepcoremonitor.CEPCoreMonitor;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.monitor.config.MonitorProcessors;
import org.tinygroup.plugin.config.PluginConfiguration;
import org.tinygroup.plugin.impl.BasePlugin;
import org.tinygroup.xstream.XStreamFactory;

import com.thoughtworks.xstream.XStream;
public class CEPCoreMonitorPlugin extends BasePlugin{
	private CEPCore cepcore; 
	private Logger logger = LoggerFactory.getLogger(CEPCoreMonitorPlugin.class);
	private CEPCoreMonitor monitor ;
	
	public void init(){
		super.init();
		initMonitor();
	}
	public void initMonitor() {
		logger.logMessage(LogLevel.DEBUG, "初始化CEPCoreMonitor");
		monitor= new CEPCoreMonitor();
		XStream stream = XStreamFactory.getXStream("cepcoremonitor");
		//stream.setClassLoader(this.getClass().getClassLoader());
		logger.logMessage(LogLevel.DEBUG, "读取cepcore-monitor配置文件");
		MonitorProcessors ms = (MonitorProcessors)stream.fromXML( this.getClass().getResourceAsStream("/cepcore-monitor.xml") );
		logger.logMessage(LogLevel.DEBUG, "读取cepcore-monitor配置文件完成");
		monitor.setMonitorProcessors(ms);
		
		
		logger.logMessage(LogLevel.DEBUG, "初始化CEPCoreMonitor完成");
	}
	protected ClassLoader getThisClassLoader(){
		 return this.getClass().getClassLoader();
	}
	public void pause() {
		logger.logMessage(LogLevel.DEBUG, "暂停CEPCoreMonitorPlugin");
		cepcore.unregisterEventProcessor(monitor);
		logger.logMessage(LogLevel.DEBUG, "暂停CEPCoreMonitorPlugin完成");
	}

	public void stop() {
		logger.logMessage(LogLevel.DEBUG, "停止CEPCoreMonitorPlugin");
		cepcore.unregisterEventProcessor(monitor);
		logger.logMessage(LogLevel.DEBUG, "停止CEPCoreMonitorPlugin完成");
	}

	public void start(){
		logger.logMessage(LogLevel.DEBUG, "启动CEPCoreMonitorPlugin");
		monitor.setMonitorObject((CEPCoreWatch)cepcore);
		cepcore.registerEventProcessor(monitor);
		logger.logMessage(LogLevel.DEBUG, "启动CEPCoreMonitorPlugin完成");
	}
	
	public void destroy(){
		logger.logMessage(LogLevel.DEBUG, "销毁CEPCoreMonitorPlugin");
		super.destroy();
		monitor = null;
		logger.logMessage(LogLevel.DEBUG, "销毁CEPCoreMonitorPlugin完成");
	}
	public <T> void setService(T service, Class<T> clazz) {
		if( CEPCore.class.isAssignableFrom(clazz)){
			if(service==null){
				this.cepcore = null;
			}else{
				this.cepcore = (CEPCore)service;
			}
		}		
	}

	public <T> void setConfig(PluginConfiguration pluginConfiguration) {
	}

	
}
